#
# spec file for package neochat
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           neochat
Version:        25.04.2
Release:        1.1
Summary:        A chat client for Matrix, the decentralized communication protocol
License:        BSD-2-Clause AND GPL-3.0-only AND GPL-3.0-or-later
Group:          Productivity/Networking/Instant Messenger
URL:            https://apps.kde.org/neochat/
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# Needed for leap 15.5
BuildRequires:  cmark
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
# Both kquickimageeditor flavors provide the same CMake target name, use the devel package name instead
# BuildRequires:  cmake(KQuickImageEditor)
BuildRequires:  kquickimageeditor6-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6ColorScheme) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemModels) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 0.7.2
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Purpose) >= %{kf6_version}
BuildRequires:  cmake(KF6QQC2DesktopStyle) >= %{kf6_version}
BuildRequires:  cmake(KF6Sonnet) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6SyntaxHighlighting) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KUnifiedPush)
BuildRequires:  cmake(QCoro6Core)
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6WebView) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(QuotientQt6) >= 0.9
BuildRequires:  pkgconfig(icu-uc) >= 61.0
BuildRequires:  pkgconfig(libcmark)
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  x86_64 %{x86_64} aarch64 riscv64
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-kitemmodels-imports >= %{kf6_version}
Requires:       kf6-kquickcharts >= %{kf6_version}
Requires:       kf6-prison-imports >= %{kf6_version}
Requires:       kf6-qqc2-desktop-style >= %{kf6_version}
Requires:       kf6-syntax-highlighting-imports >= %{kf6_version}
Requires:       kirigami-addons6 >= 0.7.2
Requires:       qt6-location >= %{qt6_version}
Requires:       qt6-positioning-imports >= %{qt6_version}
Requires:       qt6qmlimport(org.kde.kquickimageeditor.1)

%description
Neochat is a client for Matrix, the decentralized communication protocol for
instant messaging.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang %{name} --all-name --with-man

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.neochat.desktop
%{_kf6_appstreamdir}/org.kde.neochat.appdata.xml
%{_kf6_bindir}/neochat
%{_kf6_debugdir}/neochat.categories
%{_kf6_iconsdir}/hicolor/*/apps/org.kde.neochat.svg
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.neochat.tray.svg
%{_kf6_mandir}/man1/neochat.1%{?ext_man}
%dir %{_kf6_plugindir}/kf6/purpose
%{_kf6_plugindir}/kf6/purpose/neochatshareplugin.so
%{_kf6_notificationsdir}/neochat.notifyrc
%{_kf6_sharedir}/dbus-1/services/org.kde.neochat.service
%{_kf6_sharedir}/krunner/dbusplugins/plasma-runner-neochat.desktop

%files lang -f %{name}.lang

%changelog
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- Changes since 25.04.1:
  * Fix space switching on mobile (kde#504166)
  * Improve the UX for rooms that don't have a canonical alias
  * Fix GlobalMenu initialization on other platforms
  * Fix issues with global menu
  * Add padding around file progress indicator, move it to the center
  * Add duration to voice message delegate
  * CI: Remove Linux Next (Qt 6.10) job
  * Load stickers properly
  * Check if RoomEvent is null before trying to insert a notification (kde#502687)
  * Allow performing shortcuts while the completion menu is open
  * Give completion popup a minimum size when editing an existing message (kde#503483)
  * Fix crash when trying to edit your message on a wide screen (kde#503846)
  * Fix undefined reference to webShortcutModel
  * Fix the room list header margin in Kirigami >6.14
  * Make sure that ChatDocumentHandler can handle the document being changed to a nullptr (kde#501950)
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- Changes since 25.04.0:
  * Fixes a null pointer call
  * Fix two (edited) strings appearing in edited quotes
  * Fix multi-line quotes being cut off
  * LinkPreviewComponent: Fix a few bugs, restore the image preview
  * Set the pointing hand cursor shape on link previews
  * Elide the hover link indicator
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- Changes since 25.03.90:
  * snapcraft: Sync fixes into stable.
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Too many changes since 24.12.3, only listing bugfixes:
  * Make joining remote rooms more reliable (kde#487253)
  * Stop emojis from destroying your message (kde#479587)
  * Fix Getting Member Objects (kde#498649)
  * Add button to view pinned messages in a room (kde#497427)
  * Add an option to disable encryption in new chats (kde#498375)
  * Fix web shortcuts not doing anything (kde#496434)
  * Remove system information from device display name (kde#496901)
  * Make the room list slightly narrower by default (kde#496722)
  * Make sure the loading text for a new login wraps (kde#493869)
  * Fix Sed Edits (kde#496313)
  * PollHandler: Ensure that m_pollStartEvent is always initialized to null (kde#493649)
  * Make fullscreen images focused when they're opened (kde#484322)
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- Changes since 24.12.2:
  * Don't show the "Settings" button when adding a new account
  * snapcraft: Move to core24
  * StateKeys: Fix opening a specific state key member
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * Fix crash when trying to view Security settings in an invited room
  * Only build 0.9.2 tag in Flatpak manifest
  * CI: add frameworks/kiconthemes to .kde-ci.yaml
  * fix: no icon under Windows
  * Make sure space drawer icons are available for android
  * add missing icons on Android
  * Always open the user details dialog in the focused window
  * Don't spam pending invites every time NeoChat is started
  * Disable TextHandlerTest on CI
  * Improve handling of DonwloadAction
  * Expose ProgressInfoRole also for other type of attachments
  * Fix right clicking on NeoChatMaximizedComponent
  * Set explicitely parent in MaximizeComponent
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Use symbolic icon for purpose plugin
  * Explicitly set the parent in QuickSwitcher
  * Port away from methods removed in libquotient. (kde#497458)
  * [UserInfo] Fix shortcut
  * snap: use cmake snap and use . as source
  * Add better support for colored text (and shrugs) from other clients
  * Fix web shortcuts not doing anything (kde#496434)
  * Update Android Gradle plugin version to 8.6.0
  * Don't set emoji size to font size
  * Fix crash when sending messages
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * snap: Update libquotient
  * Fix removeConnection
  * Remove system information from device display name (kde#496901)
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Too many changes since 24.11.80, only listing bugfixes:
  * Make sure the loading text for a new login wraps (kde#493869)
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * PollHandler: Ensure that m_pollStartEvent is always initialized to null (kde#493649)
  * Make fullscreen images focused when they're opened (kde#484322)
  * Make send message and insert newline shortcuts configurable (kde#476758)
  * Pester Network Error Messages (kde#488572)
  * Fix crash when opening invitation (kde#493197)
  * NeochatRoomMember ID fallback (kde#491025)
  * Fix NeoChatRoom::directChatRemoteMember (kde#492733)
  * Fix Eventhandler strings for translation (kde#466201, kde#491024)
  * Use im-kick-user consistently for logout. (kde#491355)
  * Fix parsing self-closing tags with no space (such as <br/>) (kde#487377)
  * Fix default permissions settings (kde#491371)
  * Don't end kick messages without a reason with a ":" (kde#492512)
  * Re-add pending event indicator (kde#491277)
  * Fix pending events all showing the same text (kde#491277)
  * Show notification counts on the room Avatars when collapsed. (kde#468520)
  * Make sure that apostrophes are unescaped when visualising messages (kde#488325)
* Wed Nov 13 2024 Adam Mizerski <adam@mizerski.pl>
- enabled support for KUnifiedPush
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Cherry pick compatability changes for libquotient 0.9
  * snap: add snap package
- Drop patch, merged upstream:
  * 0001-Cherry-pick-compatability-changes-for-libquotient-0.patch
* Mon Oct 28 2024 Christophe Marin <christophe@krop.fr>
- Add upstream change:
  * 0001-Cherry-pick-compatability-changes-for-libquotient-0.patch
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Fix for not rendering html in replies
  * Fix compilation
  * Fix compilation against changes in libQuotient
  * Adapt to libQuotient changes
  * Unify redaction handling
  * Escape html from redaction message
  * Ensure floating buttons have correct size on mobile
  * Make sure that m_components cannot be accessed out of bounds in closeLinkPreview
  * Fix NeoChatRoom::directChatRemoteMember (kde#492733)
  * Fix crash in MessageContentModel
  * Fix display name in verification message
  * Fix filtering users in the member list
  * Don't open a room by default on mobile
  * Fix increasing font size of certain emojis
  * Use autoTransform on images
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Web Shortcuts: kcmshell5 does not exist anymore on Plasma 6
  * LocationHelper: Move clamp from zoomToFit to QML
  * AuthorDelegate: Don't make empty space clickable
  * AuthorDelegate: Add pointing hand cursor to indicate you can tap
  * Make the SectionDelegate look just a little bit better
  * Fix pending indicator
  * Use plaintext for reply author component
  * Don't run QtKeychain job in a nested event loop
  * Adapt to libQuotient API change
  * Ensure that room list does not show rooms without title during startup
  * Include missing ECMQmlModule
  * Re-add pending event indicator (kde#491277)
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Re-add pending event indicator (kde#491277)
  * Only enable taphandler for mouse clicks (kde#486545)
  * GlobalMenu: remove shortcut for QuickSwitcher (kde#488212)
  * Make notifications more useful (kde#475228)
  * Use simpler and less restrictive server url regex (kde#486888)
  * Make sure to ask before leaving a room (kde#486546)
  * Push ImageEditorPage using pushDialogLayer (kde#486315)
  * Fix the master show link preview setting and add back the per room setting (kde#486126)
  * Fix Roomlist Shortcuts (kde#485949)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * GlobalMenu: remove shortcut for QuickSwitcher (kde#488212)
  * Fix global menu
  * CI: Disable requiring Windows tests passing
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Fix keyboard navigation on search pages
  * Fix the tooltips for the two drawer buttons at the top
  * Fix keyboard navigation in space drawer
  * Add keyboard navigation for server selection in room search dialog
  * Remove room member highlight on click
  * Use Qt.alpha in ThemeRadioButton
  * Add focus border for the theme radio button, used on the Appearance page
  * Fix QR code not showing when tapping the button under account settings
  * Fix map copyright link activation
  * Don't show the map if there's no locations available
  * Fixup AttachDialog
  * CreateRoomDialog: Add missing formcard separators
  * Fix if X11 on apple
  * Cleanup quick switcher
  * Fix spacing of HiddenDelegate
  * Fix micro spacing inconsistency in SpaceHierarchyDelegate
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Fix module
  * Adapt to behavior change in libQuotient
  * Push ImageEditorPage using pushDialogLayer (kde#486315)
  * Fix opening room on mobile
  * Fix AddServerSheet
  * Revert "Preserve mx-reply in the edited message if it exists"
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Fix Roomlist Shortcuts (kde#485949)
  * Fix Verification Window Sizing (kde#485309)
  * Linkpreviewer Improvements (kde#484927)
  * Re-add requirement for having devtools active for the show message source action (kde#485140)
  * Only ask for URL opening confirmation for QR codes (kde#484870)
  * Add "Leave room" button to sidebar (kde#484425)
  * UserInfo compact (kde#482261)
  * Remove external room window feature (kde#455984)
  * Support selected text for replies in the right click menu (kde#463885)
  * Don't Maximize Stickers (kde#482701)
  * Fix Message Components for Tags with Attributes (kde#482331)
  * Fix crash when visiting user (kde#483744)
  * Remove manual window toggling for system tray icon (kde#479721)
  * Favourites -> Favorites (kde#481814)
  * Port RoomList to TreeView (kde#456643)
  * Move notifications button to space drawer. (kde#479051)
  * Readonly Room (kde#479590)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Fix crash when visiting user (kde#483744)
  * Add back Appimage job, it is fixed now
  * Remove craft-appimage-qt6
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Fix the quick format bar not actually doing anything
  * Exclude lonely question marks from the linkify regex
  * Don't destroy formatting when editing previous messages
  * Prevent collision between KUnifiedPush DBus and KRunner DBus
  * This is no longer needed now that ECM 6.0.0 is available
  * Create an APPX package for NeoChat 24.02
  * Remove manual window toggling for system tray icon (kde#479721)
  * Don't link KDBusAddons on windows
  * Don't require kirigami-addons master
  * flatpak: Switch to non-preview runtime
  * Fix (un)ignoring unknown users
  * Fix saving images from maximize component
* Thu Feb 29 2024 Christophe Marin <christophe@krop.fr>
- Update the kquickimageeditor build requirement
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Fix saving images from maximize component
  * Add feature flag for reply in thread
  * Add neochat 24.02 release note
  * Fix reaction update event when the event is not there anymore
  * Fix reaction delegate sizing for text reaction
  * Skip Welcome screen when there's only one connection and it's loaded
  * Allow dropping connections from the welcome page
  * Show custom emoji reactions as per MSC4027
  * Fix AudioDelegate playback
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Build Windows installers on invent
  * Fix crash for forbidden non-mxc media (kde#476698)
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: remove dbus slots rejected by store.
  * Add CI template for building APKs
  * snapcraft: Fix libsecret support! BUndle gnomekeychain.
    Set XDG variables so it finds keychain. Update qtkeychain.
  * snapcraft: initial import snapcraft files.
  * Use KF5 version of kirigami-addons in flatpak builds
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Use shortcode as a fallback for body when sending stickers
  * Add cmake check for qtlocation QML module
  * Add Windows-specific screenshots as screenshots with custom attribute
  * Deselect space when leaving it (kde#473271)
  * Fix opening settings (kde#473789)
  * Fix opening report sheet
  * Force plain text user display name in user detail sheet
  * Fix opening ban sheet
  * Add release note for last two version
  * Remove debuging value
* Mon Sep  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add some qt5qmlimport runtime deps (boo#1214916)
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Don't inherit color in TimelineContainer
  * Use view-list-details instead of expand icon in room drawer
  * Destroy the correct component in space list context menu
  * Prevent the TapHandler in AvatarTabButton from triggering clicked()
  * Add icons to the space list context menu items
  * Prevent the chat bar from pasting a local file URL if we save the bitmap
  * Ensure that the notification avatar is drawn with no pen
  * Further notification avatar improvements
  * Fix the account switcher width so it doesn't spill off the side
  * Pick a better shadow and clean up emoji popup backgrounds
  * Don't clip the emoji popups as they destroy shadows
  * Improve tooltips in chatbar
  * Wrap room display name in Room Drawer
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Display big emoji correctly
  * Force plain text in room delegate
  * Remove leftover debug statement
  * Fix last active time in devices page
  * Redesign timeline
  * Fix opening account menu on right click
  * Html-escape display names in state delegates
  * Fix room list icon size in compact room list (kde#472682)
  * Fix compilation with e2ee disabled
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Fix toolbar of RoomList when using font size 11px (kde#467242)
  * Don't try getting data for invalid indices (kde#470639)
  * Refactor login (kde#469486)
  * Improve Delegate Width Sizing (kde#470167)
  * Fix replying and editing from chatbox (kde#469733)
  * Fix the room timeline being dragged when selecting text (kde#467163)
  * Focus message search window's search field by default (kde#469879)
  * Cache last event (kde#455042)
  * Add more bottom margin (kde#469616)
  * Fix autocompletion not working (kde#468967)
  * Remove Unread Count (kde#466515)
  * Fix regressions from RoomPage refactoring (kde#469427)
  * Improve RoomDrawer for direct chats (kde#466895)
  * Prevent crash in SyntaxHighlighter when leaving room (kde#467722)
  * Fix handling line separators (kde#468977)
  * Fix Ctrl+Shift+, opening settings (kde#469057)
  * Fix room search field shortcut (kde#469059)
  * Fix Chat bubble background changing color when created (kde#468124)
  * Fix Long Topics in the RoomDrawer Overflowing (kde#467512)
  * Don't crash in UserListModel when there is no room (kde#466045)
  * Fix state event visiblity in timeline (kde#455048)
  * Improve Text Handling (kde#463932)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Focus message search window's search field by default (kde#469879)
  * Fix asan runtime error in texthandler
  * Update appstream description
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Don't enforce tests on windows Qt6
  * Fix handling line separators (kde#468977)
  * Prevent crash in SyntaxHighlighter when leaving room (kde#467722)
  * Add loading title to LoadingPage
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sat Mar 18 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Wed Feb 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.01.0
  * notifications are now shown for all accounts
  * new compact mode for the room list
  * searching in history is now possible
  * emojis and reactions improvements
* Mon Jan 23 2023 Tamara Schmitz <tschmitz@suse.com>
- update to 22.11:
  * work on end-to-end encryption implementation
  * configuration settings ported to new form components
  * new settings component for managing notifications settings
  * add proxy configuration menu
  * added developer tools for inspecting raw matrix events
  * added confirmation dialog when signing out and when enabling end-to-end encryption
  * rewrite of theaccount switcher
- fix buildrequires, remove redundant requires
- fix permissions of license file
* Thu Sep 29 2022 Dirk Müller <dmueller@suse.com>
- update to 22.09:
  * implemented support for configuring notifications on a per-room basis. As
    part of his GSoC project, Snehit added a space selector to the room list,
    which allows filtering the room list for rooms included in the selected
    space. James also reworked the timeline layout to make it look nicer when
    the window is very wide. There have also been a ton of other fixes and
    improvements in translations, the layout and the stability of NeoChat.
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Use GCC 10 to build neochat on Leap.
* Wed Aug  3 2022 Dirk Müller <dmueller@suse.com>
- update to 22.06:
  * Sending of typing notifications can now be disabled.
  * In the room list, the scrollbar will now disappear correctly when it is not needed.
  * On wayland, NeoChat will now raise correctly when clicking on a notification.
  * Several bugs have been fixed that would sometimes cause messages containing
    markdown and/or HTML elements to be sent incorrectly.
  * The quick switcher can now be controlled using the mouse.
  * There is now an option to disable automatic room sidebar opening when
    resizing the window.
  * Creation of custom emojis has been fixed.
  * Editing or replying to the last message using the keyboard shortcuts now
    works correctly.
  * When switching between rooms using the keyboard, the switching direction is
    now correct.
* Tue Mar 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update the QCoro build dependency.
* Wed Feb  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 22.02:
  * Implement sharing with Purpose (export)
  * Implement adding labels for account
  * Give settings window a title
  * Reduce minimum height of the window
  * Fix build with qcoro 0.4
  * Fix issues with saveFileAs
  * Changed “Settings” to “Configure NeoChat” in menu
  * Improve toolbar on mobile
  * Improve emoji pane
  * Check if password can be changed
  * Fix image tooltip
  * Adapt list setting pages to new style
  * Allow using ESC to go back to room list
  * Port away from QNetworkConfigurationManager
  * Remove lag when starting user autocompletion
  * Set single window hint in desktop file
  * Make room address selectable
  * Display monochrome icon in tray
  * Fix QuickSwitcher activation
  * Fix Windows/mac build
  * Fix notifications on Android
  * Support raising when we receive a notification
  * Don’t render html in RoomDrawer heading
  * Add support for minimizing to system tray on startup
  * Use non blocking passord reading
  * Add a mobile oriented context menu for the room list
  * Fix loading room settings on mobile
  * Use icon from qrc for system tray icon
  * Adapt to libQuotient API change
* Mon Feb  7 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 21.12:
  * Solved various problems related to login, logout and account switching
  * Fixed a few problems in the timeline layout
  * Added Spell checking while writing a message
  * Improved Settings pages
  * Many improvements to the android and general mobile support
  * Show blurhashes while images load
  * Support showing custom emojis
  * Added a global menu
  * Added support for spoilers
  * Added a quick switcher to switch between rooms
  * Added support for an optional fancy blur background effect
  * Resizable left and right drawers
  * Added Syntax highlighting in raw json messages
  * Better wayland support
  * Improved file reception and download
- Part of Plasma Mobile Gear now, adjust URL and neochat.keyring
* Sat Jun 26 2021 ecsos <ecsos@opensuse.org>
- Fix build error.
  - Add missig cmark which will not be install with libcmark-devel.
* Tue Jun  1 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.2.0
  * major UI redesign
  * chage page is now using bubbles
  * it's now possible to send custom reactions by replying
    to a comment with /react <message>
  * now supports opening Matrix URI from the web browser
* Thu Feb 25 2021 ecsos <ecsos@opensuse.org>
- Update to 1.1.1
  - First launch experience improvements
  - Allow logins to servers requiring SSO
  - Display stickers
  - Allow editing messages
  - Multimodal mode to open a room into a new window
  - New chat commands
  - Better Plasma integration
* Mon Feb 15 2021 Tomas Cech <sleep_walker@opensuse.org>
- Add missing require libqt5-qtquickcontrols again.
* Sat Jan 16 2021 Luca Beltrame <lbeltrame@kde.org>
- Adjust spec file to conform to the KDE team's guidelines
* Wed Jan 13 2021 ecsos <ecsos@opensuse.org>
- Update to 1.0.1
  - NeoChat doesn't require a .well-know configuration in the
    server to work.
  - Edited messages won’t show up duplicated anymore.
  - NeoChat now ask for consent to terms and conditions if required
    instead of displaying nothing.
  - Users avatar in the room list are now displayed correctly.
  - Fix image saving
  - Various graphic glitches have been fixed.
- Switch source from invent.kde.org to download.kde.org, because in
  git is not always the newest tar.
- Add language subpackages.
* Mon Jan  4 2021 ecsos <ecsos@opensuse.org>
- Add missing require libqt5-qtquickcontrols.
* Wed Dec 23 2020 ecsos <ecsos@opensuse.org>
- Change from git version to version 1.0
* Mon Nov 23 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
